@@ -5,9 +5,8 @@ use crate::{
     util::{make_bool, ValueExt},
 };
 use swc_atoms::js_word;
-use swc_common::EqIgnoreSpan;
+use swc_common::{util::take::Take, EqIgnoreSpan};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ident::IdentLike, ExprExt, Type, Value};
 use Value::Known;
 
